#
# spec file for package intel-opencl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           intel-opencl
Version:        23.22.26516.18
Release:        1.2
Summary:        Intel Graphics Compute Runtime for OpenCL
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/intel/compute-runtime
Source0:        https://github.com/intel/compute-runtime/archive/%{version}/compute-runtime-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  level-zero-devel
BuildRequires:  libigc-devel
BuildRequires:  libigdgmm-devel >= 22.3.0
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(igc-opencl)
BuildRequires:  pkgconfig(libva)
Requires:       libigc1
Requires:       libigdfcl1
Requires:       libopencl-clang14
ExclusiveArch:  x86_64

%description
Intel Graphics Compute Runtime for OpenCL.

%package devel
Summary:        Headers for the Intel Graphics Compute Runtime OpenCL Driver
Requires:       %{name} = %{version}-%{release}

%description devel
Development package for Intel Graphics Compute Runtime for OpenCL.

%prep
%autosetup -p1 -n compute-runtime-%{version}

%build
%define __builder ninja

# Needed for gcc12+
%if 0%{?suse_version} > 1500
export CXXFLAGS="-Wno-error=maybe-uninitialized -Wno-error=mismatched-new-delete"
%endif

%cmake \
  -DSKIP_UNIT_TESTS=1
%cmake_build

%install
%cmake_install
chmod +x %{buildroot}%{_libdir}/intel-opencl/libigdrcl.so
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}/%{_datadir}/OpenCL/vendors
mv %{buildroot}/%{_sysconfdir}/OpenCL/vendors/intel.icd %{buildroot}/%{_datadir}/OpenCL/vendors/
%endif
rm -Rf %{buildroot}%{_prefix}/lib/debug

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_libdir}/intel-opencl/libigdrcl.so
%{_libdir}/libocloc.so
%{_libdir}/libze_intel_gpu.so.1
%{_libdir}/libze_intel_gpu.so.1.3.*
%{_bindir}/ocloc
%{_libdir}/intel-opencl
%if 0%{?suse_version} > 1500
%{_datadir}/OpenCL
%{_datadir}/OpenCL/vendors
%{_datadir}/OpenCL/vendors/intel.icd
%else
%{_sysconfdir}/OpenCL
%{_sysconfdir}/OpenCL/vendors
%{_sysconfdir}/OpenCL/vendors/intel.icd
%endif

%files devel
%{_includedir}/ocloc_api.h
%{_includedir}/zet_intel_gpu_debug.h

%changelog
* Wed Aug 23 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Use libopencl-clang14 from the intel-graphics-compiler llvm14 build
* Wed Aug 23 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 23.22.26516.18
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Drop R/TM markup as per
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Mon May 29 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- 0001-include-cstdint-needed-when-compiling-with-gcc13.patch no longer needed
* Wed May 24 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 23.13.26032.30
* Tue Mar 28 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 23.05.25593.11
- Now builds against level-zero
- New fixes for building with gcc13
- supersedes 0001-Include-memory-in-generate_cpp_array.cpp.patch
* Mon Mar 27 2023 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Fix build issues for missing include of cstdio with gcc13
  * 0001-include-cstdint-needed-when-compiling-with-gcc13.patch
* Wed Nov  9 2022 Stefan Dirsch <sndirsch@suse.com>
- keep icd file in /etc/OpenCL/vendors on Leap 15.x/sle-15-SPx
* Thu Jun  9 2022 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Add requirements for libigc1, libigdfcl1 and libopencl-clang11
* Fri May 13 2022 Patrik Jakobsson <patrik.jakobsson@suse.com>
- 0001-Include-memory-in-generate_cpp_array.cpp.patch
  * Include <memory> in generate_cpp_array.cpp
* Thu May 12 2022 Patrik Jakobsson <patrik.jakobsson@suse.com>
- gcc12 introduced new warnings that must not be treated as errors
- Include <memory> in generate_cpp_array.cpp
* Thu Nov 11 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 21.43.21438
  * Linked with gmmlib on all architectures
  * Exposed clGetKernelSuggestedLocalWorkSizeKHR func
  * igsc revision updated
* Sat Oct 30 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- spec-clean cleanup
- Description fix
- Set a release
* Thu Oct 28 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Only build for x86_64
* Thu Oct 28 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Since the IGC package is now split up in libs, use libigc-devel instead
* Wed Oct  6 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 21.39.21127
  * Updated IGC
  * Updated metric_library_api header file
  * Added ADLS device id (jsc#SLE-18964)
* Tue Sep 28 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 21.38.21026
  * Updated IGC, opencl-clang, VC intrinsics, spirv-translator built with
    llvm 11
  * Updated igsc
  * Updated L0 loader
* Sat Sep 25 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Make sure we have a sufficiently recent version of libigdgmm-devel
* Fri Sep 24 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Add requirement on intel-graphics-compiler-opencl
* Tue Sep 14 2021 Patrik Jakobsson <patrik.jakobsson@suse.com>
- Update to version 21.36.20889 (jsc#SLE-20149)
  * OpenCL and Level Zero packages provided in this release were compiled
    with DG1 support disabled.
  * Binary packages were repackaged to fix dependency issue with IGC
    release 1.0.8517. Please use IGC packages with version number 1.0.8517.
- Move icd file into default directory
* Mon Mar 23 2020 Martin Pluskal <mpluskal@suse.com>
- Initial changelog entry for version 20.11.16158
